"""Base components."""

from .body import Body
from .document import ColorModeScript, DocumentHead, Html, Main, Script
from .head import Head
from .link import Link, ScriptTag
from .meta import Description, Image, Meta, Title
